@@ -27,7 +27,7 @@ def skip_without_credentials(func):
     vnet = dask.config.get("cloudprovider.azure.azurevm.vnet", None)
     security_group = dask.config.get("cloudprovider.azure.azurevm.security_group", None)
     location = dask.config.get("cloudprovider.azure.location", None)
-    if rg is None or vnet is None or security_group or location is None:
+    if rg is None or vnet is None or security_group is None or location is None:
         return pytest.mark.skip(
             reason="""
         You must configure your Azure resource group and vnet to run this test.
@@ -60,9 +60,9 @@ async def test_create_cluster():
     async with AzureVMCluster(asynchronous=True) as cluster:
         assert cluster.status == Status.running
 
-        cluster.scale(1)
+        cluster.scale(2)
         await cluster
-        assert len(cluster.workers) == 1
+        assert len(cluster.workers) == 2
 
         async with Client(cluster, asynchronous=True) as client:
 
@@ -114,3 +114,10 @@ async def test_create_rapids_cluster_sync():
             for w, res in results.items():
                 assert "total" in res["gpu"][0]["fb_memory_usage"].keys()
                 print(res)
+
+
+@pytest.mark.asyncio
+@skip_without_credentials
+async def test_render_cloud_init():
+    cloud_init = AzureVMCluster.get_cloud_init(docker_args="--privileged")
+    assert " --privileged " in cloud_init
